@@ -1,23 +1,25 @@
+from enum import Enum
+
 class Integration:
 
-    class Types:
+    class Types(Enum):
         CSV = 'CSV'
         EXCEL = 'EXCEL'
         GOOGLESPREADSHEET = 'GOOGLE SPREADSHEET'
 
-    class Modes:
+    class Modes(Enum):
         READ = 'READ'
         WRITE = 'WRITE'
 
 class WebScraper:
 
-    class Functions:
+    class Functions(Enum):
         SUBSTRING = 'substring'
         EXPLODE = 'explode'
         REPLACE = 'join'
         JOIN = 'join'
 
-    class Types:
+    class Types(Enum):
         PERCENTAGE = 'PERCENTAGE'
         BOOL = 'BOOL'
         MONEY = 'MONEY'
@@ -31,16 +33,17 @@ class WebScraper:
         JSON = 'JSON'
         STRING = 'STRING'
 
-    class Properties:
+    class Properties(Enum):
         TEXT = 'text()'
         HTML = 'html()'
 
 class Requests:
 
-    class Types:
+    class Methods(Enum):
         POST = 'POST'
         GET = 'GET'
+        PUT = 'PUT'
     
-    class Responses:
+    class ResponseTypes(Enum):
         TEXT = 'TEXT'
         JSON = 'JSON'
