@@ -3,12 +3,6 @@ from scrapeanything.database.repository import Repository
 from scrapeanything.database.models import Model
 from scrapeanything.utils.constants import *
 import requests
-from enum import Enum
-
-class Methods(Enum):
-    POST = 'POST'
-    GET = 'GET'
-    PUT = 'PUT'
 
 class Service:
 
@@ -34,7 +28,7 @@ class Service:
     def save(self, entity: Model) -> None:
         self.repository.save(entity=entity)
 
-    def wget(self, url: str, parameters: dict=None, method: Methods=Methods.GET, response_type: str=WebScraper.Types.JSON) -> any:
+    def wget(self, url: str, parameters: dict=None, method: Methods=Requests.Methods.GET, response_type: Requests.ResponseTypes=Requests.ResponseTypes.JSON) -> any:
         if method == Methods.GET:
             response = requests.get(url=url, data=parameters)
         elif method == Methods.POST:
